@@ -2,10 +2,12 @@ from __future__ import annotations
 
 import os
 import shutil
+import subprocess
 import sys
 
 from pathlib import Path
 from typing import TYPE_CHECKING
+from typing import Any
 
 import pytest
 
@@ -13,7 +15,7 @@ from cleo.testers.command_tester import CommandTester
 from packaging.utils import canonicalize_name
 
 from poetry.console.commands.init import InitCommand
-from poetry.repositories import Pool
+from poetry.repositories import RepositoryPool
 from poetry.utils._compat import decode
 from tests.helpers import PoetryTestApplication
 from tests.helpers import get_package
@@ -26,6 +28,7 @@ if TYPE_CHECKING:
     from poetry.core.packages.package import Package
     from pytest_mock import MockerFixture
 
+    from poetry.config.config import Config
     from poetry.poetry import Poetry
     from tests.helpers import TestRepository
     from tests.types import FixtureDirGetter
@@ -46,7 +49,8 @@ def source_dir(tmp_path: Path) -> Iterator[Path]:
 def patches(mocker: MockerFixture, source_dir: Path, repo: TestRepository) -> None:
     mocker.patch("pathlib.Path.cwd", return_value=source_dir)
     mocker.patch(
-        "poetry.console.commands.init.InitCommand._get_pool", return_value=Pool([repo])
+        "poetry.console.commands.init.InitCommand._get_pool",
+        return_value=RepositoryPool([repo]),
     )
 
 
@@ -843,13 +847,15 @@ def test_predefined_all_options(tester: CommandTester, repo: TestRepository):
     ]
 
     tester.execute(
-        "--name my-package "
-        "--description 'This is a description' "
-        "--author 'Foo Bar <foo@example.com>' "
-        "--python '^3.8' "
-        "--license MIT "
-        "--dependency pendulum "
-        "--dev-dependency pytest",
+        (
+            "--name my-package "
+            "--description 'This is a description' "
+            "--author 'Foo Bar <foo@example.com>' "
+            "--python '^3.8' "
+            "--license MIT "
+            "--dependency pendulum "
+            "--dev-dependency pytest"
+        ),
         inputs="\n".join(inputs),
     )
 
@@ -940,10 +946,12 @@ line-length = 88
     repo.add_package(get_package("foo", "1.19.2"))
 
     tester.execute(
-        "--author 'Your Name <you@example.com>' "
-        "--name 'my-package' "
-        "--python '^3.6' "
-        "--dependency foo",
+        (
+            "--author 'Your Name <you@example.com>' "
+            "--name 'my-package' "
+            "--python '^3.6' "
+            "--dependency foo"
+        ),
         interactive=False,
     )
 
@@ -1005,3 +1013,97 @@ def test__validate_package_valid(name: str | None):
 def test__validate_package_invalid(name: str):
     with pytest.raises(ValueError):
         assert InitCommand._validate_package(name)
+
+
+@pytest.mark.parametrize(
+    "package_name, include",
+    (
+        ("mypackage", None),
+        ("my-package", "my_package"),
+        ("my.package", "my"),
+        ("my-awesome-package", "my_awesome_package"),
+        ("my.awesome.package", "my"),
+    ),
+)
+def test_package_include(
+    tester: CommandTester,
+    package_name: str,
+    include: str | None,
+):
+    tester.execute(
+        inputs="\n".join(
+            (
+                package_name,
+                "",  # Version
+                "",  # Description
+                "poetry",  # Author
+                "",  # License
+                "^3.10",  # Python
+                "n",  # Interactive packages
+                "n",  # Interactive dev packages
+                "\n",  # Generate
+            ),
+        ),
+    )
+
+    if include is None:
+        packages = ""
+    else:
+        packages = f'packages = [{{include = "{include}"}}]\n'
+
+    expected = (
+        f"[tool.poetry]\n"
+        f'name = "{package_name.replace(".", "-")}"\n'  # canonicalized
+        f'version = "0.1.0"\n'
+        f'description = ""\n'
+        f'authors = ["poetry"]\n'
+        f'readme = "README.md"\n'
+        f"{packages}"  # This line is optional. Thus no newline here.
+        f"\n"
+        f"[tool.poetry.dependencies]\n"
+        f'python = "^3.10"\n'
+    )
+    assert expected in tester.io.fetch_output()
+
+
+@pytest.mark.parametrize(
+    ["prefer_active", "python"],
+    [
+        (True, "1.1"),
+        (False, f"{sys.version_info[0]}.{sys.version_info[1]}"),
+    ],
+)
+def test_respect_prefer_active_on_init(
+    prefer_active: bool,
+    python: str,
+    config: Config,
+    mocker: MockerFixture,
+    tester: CommandTester,
+    source_dir: Path,
+):
+    from poetry.utils.env import GET_PYTHON_VERSION_ONELINER
+
+    orig_check_output = subprocess.check_output
+
+    def mock_check_output(cmd: str, *_: Any, **__: Any) -> str:
+        if GET_PYTHON_VERSION_ONELINER in cmd:
+            return "1.1.1"
+
+        return orig_check_output(cmd, *_, **__)
+
+    mocker.patch("subprocess.check_output", side_effect=mock_check_output)
+
+    config.config["virtualenvs"]["prefer-active-python"] = prefer_active
+    pyproject_file = source_dir / "pyproject.toml"
+
+    tester.execute(
+        "--author 'Your Name <you@example.com>' --name 'my-package'",
+        interactive=False,
+    )
+
+    expected = f"""\
+[tool.poetry.dependencies]
+python = "^{python}"
+"""
+
+    assert expected in pyproject_file.read_text()
